@@ -1,7 +1,7 @@
 """
 Type annotations for honeycode service client.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client/)
 
 Usage::
 
@@ -81,7 +81,7 @@ class Exceptions:
 class HoneycodeClient(BaseClient):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/honeycode.html#Honeycode.Client)
-    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client/)
     """
 
     meta: ClientMeta
@@ -92,7 +92,7 @@ class HoneycodeClient(BaseClient):
         HoneycodeClient exceptions.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/honeycode.html#Honeycode.Client.exceptions)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#exceptions)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client/#exceptions)
         """
 
     def batch_create_table_rows(
@@ -100,7 +100,7 @@ class HoneycodeClient(BaseClient):
         *,
         workbookId: str,
         tableId: str,
-        rowsToCreate: Sequence["CreateRowDataTypeDef"],
+        rowsToCreate: Sequence[CreateRowDataTypeDef],
         clientRequestToken: str = ...
     ) -> BatchCreateTableRowsResultTypeDef:
         """
@@ -108,7 +108,7 @@ class HoneycodeClient(BaseClient):
         a table in a workbook.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/honeycode.html#Honeycode.Client.batch_create_table_rows)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#batch_create_table_rows)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client/#batch_create_table_rows)
         """
 
     def batch_delete_table_rows(
@@ -119,7 +119,7 @@ class HoneycodeClient(BaseClient):
         in a workbook.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/honeycode.html#Honeycode.Client.batch_delete_table_rows)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#batch_delete_table_rows)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client/#batch_delete_table_rows)
         """
 
     def batch_update_table_rows(
@@ -127,7 +127,7 @@ class HoneycodeClient(BaseClient):
         *,
         workbookId: str,
         tableId: str,
-        rowsToUpdate: Sequence["UpdateRowDataTypeDef"],
+        rowsToUpdate: Sequence[UpdateRowDataTypeDef],
         clientRequestToken: str = ...
     ) -> BatchUpdateTableRowsResultTypeDef:
         """
@@ -135,7 +135,7 @@ class HoneycodeClient(BaseClient):
         a workbook.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/honeycode.html#Honeycode.Client.batch_update_table_rows)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#batch_update_table_rows)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client/#batch_update_table_rows)
         """
 
     def batch_upsert_table_rows(
@@ -143,14 +143,14 @@ class HoneycodeClient(BaseClient):
         *,
         workbookId: str,
         tableId: str,
-        rowsToUpsert: Sequence["UpsertRowDataTypeDef"],
+        rowsToUpsert: Sequence[UpsertRowDataTypeDef],
         clientRequestToken: str = ...
     ) -> BatchUpsertTableRowsResultTypeDef:
         """
         The BatchUpsertTableRows API allows you to upsert one or more rows in a table.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/honeycode.html#Honeycode.Client.batch_upsert_table_rows)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#batch_upsert_table_rows)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client/#batch_upsert_table_rows)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
@@ -158,7 +158,15 @@ class HoneycodeClient(BaseClient):
         Check if an operation can be paginated.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/honeycode.html#Honeycode.Client.can_paginate)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#can_paginate)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client/#can_paginate)
+        """
+
+    def close(self) -> None:
+        """
+        Closes underlying endpoint connections.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/honeycode.html#Honeycode.Client.close)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client/#close)
         """
 
     def describe_table_data_import_job(
@@ -169,7 +177,7 @@ class HoneycodeClient(BaseClient):
         of a table data import job.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/honeycode.html#Honeycode.Client.describe_table_data_import_job)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#describe_table_data_import_job)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client/#describe_table_data_import_job)
         """
 
     def generate_presigned_url(
@@ -183,7 +191,7 @@ class HoneycodeClient(BaseClient):
         Generate a presigned url given a client, its method, and arguments.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/honeycode.html#Honeycode.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#generate_presigned_url)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client/#generate_presigned_url)
         """
 
     def get_screen_data(
@@ -192,7 +200,7 @@ class HoneycodeClient(BaseClient):
         workbookId: str,
         appId: str,
         screenId: str,
-        variables: Mapping[str, "VariableValueTypeDef"] = ...,
+        variables: Mapping[str, VariableValueTypeDef] = ...,
         maxResults: int = ...,
         nextToken: str = ...
     ) -> GetScreenDataResultTypeDef:
@@ -200,7 +208,7 @@ class HoneycodeClient(BaseClient):
         The GetScreenData API allows retrieval of data from a screen in a Honeycode app.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/honeycode.html#Honeycode.Client.get_screen_data)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#get_screen_data)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client/#get_screen_data)
         """
 
     def invoke_screen_automation(
@@ -210,7 +218,7 @@ class HoneycodeClient(BaseClient):
         appId: str,
         screenId: str,
         screenAutomationId: str,
-        variables: Mapping[str, "VariableValueTypeDef"] = ...,
+        variables: Mapping[str, VariableValueTypeDef] = ...,
         rowId: str = ...,
         clientRequestToken: str = ...
     ) -> InvokeScreenAutomationResultTypeDef:
@@ -219,7 +227,7 @@ class HoneycodeClient(BaseClient):
         a Honeycode app.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/honeycode.html#Honeycode.Client.invoke_screen_automation)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#invoke_screen_automation)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client/#invoke_screen_automation)
         """
 
     def list_table_columns(
@@ -230,7 +238,7 @@ class HoneycodeClient(BaseClient):
         table in a workbook.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/honeycode.html#Honeycode.Client.list_table_columns)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#list_table_columns)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client/#list_table_columns)
         """
 
     def list_table_rows(
@@ -247,7 +255,7 @@ class HoneycodeClient(BaseClient):
         in a workbook.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/honeycode.html#Honeycode.Client.list_table_rows)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#list_table_rows)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client/#list_table_rows)
         """
 
     def list_tables(
@@ -258,7 +266,7 @@ class HoneycodeClient(BaseClient):
         workbook.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/honeycode.html#Honeycode.Client.list_tables)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#list_tables)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client/#list_tables)
         """
 
     def list_tags_for_resource(self, *, resourceArn: str) -> ListTagsForResourceResultTypeDef:
@@ -266,7 +274,7 @@ class HoneycodeClient(BaseClient):
         The ListTagsForResource API allows you to return a resource's tags.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/honeycode.html#Honeycode.Client.list_tags_for_resource)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#list_tags_for_resource)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client/#list_tags_for_resource)
         """
 
     def query_table_rows(
@@ -274,7 +282,7 @@ class HoneycodeClient(BaseClient):
         *,
         workbookId: str,
         tableId: str,
-        filterFormula: "FilterTypeDef",
+        filterFormula: FilterTypeDef,
         maxResults: int = ...,
         nextToken: str = ...
     ) -> QueryTableRowsResultTypeDef:
@@ -283,24 +291,24 @@ class HoneycodeClient(BaseClient):
         rows in a table.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/honeycode.html#Honeycode.Client.query_table_rows)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#query_table_rows)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client/#query_table_rows)
         """
 
     def start_table_data_import_job(
         self,
         *,
         workbookId: str,
-        dataSource: "ImportDataSourceTypeDef",
+        dataSource: ImportDataSourceTypeDef,
         dataFormat: Literal["DELIMITED_TEXT"],
         destinationTableId: str,
-        importOptions: "ImportOptionsTypeDef",
+        importOptions: ImportOptionsTypeDef,
         clientRequestToken: str
     ) -> StartTableDataImportJobResultTypeDef:
         """
         The StartTableDataImportJob API allows you to start an import job on a table.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/honeycode.html#Honeycode.Client.start_table_data_import_job)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#start_table_data_import_job)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client/#start_table_data_import_job)
         """
 
     def tag_resource(self, *, resourceArn: str, tags: Mapping[str, str]) -> Dict[str, Any]:
@@ -308,7 +316,7 @@ class HoneycodeClient(BaseClient):
         The TagResource API allows you to add tags to an ARN-able resource.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/honeycode.html#Honeycode.Client.tag_resource)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#tag_resource)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client/#tag_resource)
         """
 
     def untag_resource(self, *, resourceArn: str, tagKeys: Sequence[str]) -> Dict[str, Any]:
@@ -316,7 +324,7 @@ class HoneycodeClient(BaseClient):
         The UntagResource API allows you to removes tags from an ARN-able resource.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/honeycode.html#Honeycode.Client.untag_resource)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#untag_resource)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client/#untag_resource)
         """
 
     @overload
@@ -325,26 +333,26 @@ class HoneycodeClient(BaseClient):
     ) -> ListTableColumnsPaginator:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/honeycode.html#Honeycode.Client.get_paginator)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#get_paginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client/#get_paginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_table_rows"]) -> ListTableRowsPaginator:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/honeycode.html#Honeycode.Client.get_paginator)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#get_paginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client/#get_paginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_tables"]) -> ListTablesPaginator:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/honeycode.html#Honeycode.Client.get_paginator)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#get_paginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client/#get_paginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["query_table_rows"]) -> QueryTableRowsPaginator:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/honeycode.html#Honeycode.Client.get_paginator)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client.html#get_paginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_honeycode/client/#get_paginator)
         """
