@@ -1,14 +1,14 @@
 """
 Type annotations for honeycode service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_honeycode/type_defs.html)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_honeycode/type_defs/)
 
 Usage::
 
     ```python
-    from mypy_boto3_honeycode.type_defs import BatchCreateTableRowsRequestRequestTypeDef
+    from mypy_boto3_honeycode.type_defs import FailedBatchItemTypeDef
 
-    data: BatchCreateTableRowsRequestRequestTypeDef = {...}
+    data: FailedBatchItemTypeDef = {...}
     ```
 """
 import sys
@@ -34,93 +34,77 @@ else:
 
 
 __all__ = (
-    "BatchCreateTableRowsRequestRequestTypeDef",
-    "BatchCreateTableRowsResultTypeDef",
+    "FailedBatchItemTypeDef",
     "BatchDeleteTableRowsRequestRequestTypeDef",
-    "BatchDeleteTableRowsResultTypeDef",
-    "BatchUpdateTableRowsRequestRequestTypeDef",
-    "BatchUpdateTableRowsResultTypeDef",
-    "BatchUpsertTableRowsRequestRequestTypeDef",
-    "BatchUpsertTableRowsResultTypeDef",
+    "UpsertRowsResultTypeDef",
     "CellInputTypeDef",
     "CellTypeDef",
     "ColumnMetadataTypeDef",
-    "CreateRowDataTypeDef",
     "DataItemTypeDef",
+    "DelimitedTextImportOptionsOutputTypeDef",
     "DelimitedTextImportOptionsTypeDef",
     "DescribeTableDataImportJobRequestRequestTypeDef",
-    "DescribeTableDataImportJobResultTypeDef",
-    "DestinationOptionsTypeDef",
-    "FailedBatchItemTypeDef",
+    "SourceDataColumnPropertiesOutputTypeDef",
+    "SourceDataColumnPropertiesTypeDef",
     "FilterTypeDef",
-    "GetScreenDataRequestRequestTypeDef",
-    "GetScreenDataResultTypeDef",
+    "VariableValueTypeDef",
+    "ImportDataSourceConfigOutputTypeDef",
     "ImportDataSourceConfigTypeDef",
-    "ImportDataSourceTypeDef",
     "ImportJobSubmitterTypeDef",
-    "ImportOptionsTypeDef",
-    "InvokeScreenAutomationRequestRequestTypeDef",
     "InvokeScreenAutomationResultTypeDef",
+    "ListTableColumnsRequestListTableColumnsPaginateTypeDef",
     "ListTableColumnsRequestRequestTypeDef",
-    "ListTableColumnsResultTypeDef",
+    "TableColumnTypeDef",
+    "ListTableRowsRequestListTableRowsPaginateTypeDef",
     "ListTableRowsRequestRequestTypeDef",
-    "ListTableRowsResultTypeDef",
+    "ListTablesRequestListTablesPaginateTypeDef",
     "ListTablesRequestRequestTypeDef",
-    "ListTablesResultTypeDef",
+    "TableTypeDef",
     "ListTagsForResourceRequestRequestTypeDef",
     "ListTagsForResourceResultTypeDef",
     "PaginatorConfigTypeDef",
-    "QueryTableRowsRequestRequestTypeDef",
-    "QueryTableRowsResultTypeDef",
     "ResponseMetadataTypeDef",
-    "ResultRowTypeDef",
-    "ResultSetTypeDef",
-    "SourceDataColumnPropertiesTypeDef",
-    "StartTableDataImportJobRequestRequestTypeDef",
     "StartTableDataImportJobResultTypeDef",
-    "TableColumnTypeDef",
-    "TableDataImportJobMetadataTypeDef",
-    "TableRowTypeDef",
-    "TableTypeDef",
     "TagResourceRequestRequestTypeDef",
     "UntagResourceRequestRequestTypeDef",
-    "UpdateRowDataTypeDef",
-    "UpsertRowDataTypeDef",
-    "UpsertRowsResultTypeDef",
-    "VariableValueTypeDef",
-)
-
-_RequiredBatchCreateTableRowsRequestRequestTypeDef = TypedDict(
-    "_RequiredBatchCreateTableRowsRequestRequestTypeDef",
-    {
-        "workbookId": str,
-        "tableId": str,
-        "rowsToCreate": Sequence["CreateRowDataTypeDef"],
-    },
-)
-_OptionalBatchCreateTableRowsRequestRequestTypeDef = TypedDict(
-    "_OptionalBatchCreateTableRowsRequestRequestTypeDef",
-    {
-        "clientRequestToken": str,
-    },
-    total=False,
-)
-
-
-class BatchCreateTableRowsRequestRequestTypeDef(
-    _RequiredBatchCreateTableRowsRequestRequestTypeDef,
-    _OptionalBatchCreateTableRowsRequestRequestTypeDef,
-):
-    pass
-
-
-BatchCreateTableRowsResultTypeDef = TypedDict(
     "BatchCreateTableRowsResultTypeDef",
+    "BatchDeleteTableRowsResultTypeDef",
+    "BatchUpdateTableRowsResultTypeDef",
+    "BatchUpsertTableRowsResultTypeDef",
+    "CreateRowDataTypeDef",
+    "UpdateRowDataTypeDef",
+    "TableRowTypeDef",
+    "ResultRowTypeDef",
+    "DestinationOptionsOutputTypeDef",
+    "DestinationOptionsTypeDef",
+    "QueryTableRowsRequestQueryTableRowsPaginateTypeDef",
+    "QueryTableRowsRequestRequestTypeDef",
+    "UpsertRowDataTypeDef",
+    "GetScreenDataRequestRequestTypeDef",
+    "InvokeScreenAutomationRequestRequestTypeDef",
+    "ImportDataSourceOutputTypeDef",
+    "ImportDataSourceTypeDef",
+    "ListTableColumnsResultTypeDef",
+    "ListTablesResultTypeDef",
+    "BatchCreateTableRowsRequestRequestTypeDef",
+    "BatchUpdateTableRowsRequestRequestTypeDef",
+    "ListTableRowsResultTypeDef",
+    "QueryTableRowsResultTypeDef",
+    "ResultSetTypeDef",
+    "ImportOptionsOutputTypeDef",
+    "ImportOptionsTypeDef",
+    "BatchUpsertTableRowsRequestRequestTypeDef",
+    "GetScreenDataResultTypeDef",
+    "TableDataImportJobMetadataTypeDef",
+    "StartTableDataImportJobRequestRequestTypeDef",
+    "DescribeTableDataImportJobResultTypeDef",
+)
+
+FailedBatchItemTypeDef = TypedDict(
+    "FailedBatchItemTypeDef",
     {
-        "workbookCursor": int,
-        "createdRows": Dict[str, str],
-        "failedBatchItems": List["FailedBatchItemTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "id": str,
+        "errorMessage": str,
     },
 )
 
@@ -148,79 +132,11 @@ class BatchDeleteTableRowsRequestRequestTypeDef(
     pass
 
 
-BatchDeleteTableRowsResultTypeDef = TypedDict(
-    "BatchDeleteTableRowsResultTypeDef",
+UpsertRowsResultTypeDef = TypedDict(
+    "UpsertRowsResultTypeDef",
     {
-        "workbookCursor": int,
-        "failedBatchItems": List["FailedBatchItemTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-_RequiredBatchUpdateTableRowsRequestRequestTypeDef = TypedDict(
-    "_RequiredBatchUpdateTableRowsRequestRequestTypeDef",
-    {
-        "workbookId": str,
-        "tableId": str,
-        "rowsToUpdate": Sequence["UpdateRowDataTypeDef"],
-    },
-)
-_OptionalBatchUpdateTableRowsRequestRequestTypeDef = TypedDict(
-    "_OptionalBatchUpdateTableRowsRequestRequestTypeDef",
-    {
-        "clientRequestToken": str,
-    },
-    total=False,
-)
-
-
-class BatchUpdateTableRowsRequestRequestTypeDef(
-    _RequiredBatchUpdateTableRowsRequestRequestTypeDef,
-    _OptionalBatchUpdateTableRowsRequestRequestTypeDef,
-):
-    pass
-
-
-BatchUpdateTableRowsResultTypeDef = TypedDict(
-    "BatchUpdateTableRowsResultTypeDef",
-    {
-        "workbookCursor": int,
-        "failedBatchItems": List["FailedBatchItemTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-_RequiredBatchUpsertTableRowsRequestRequestTypeDef = TypedDict(
-    "_RequiredBatchUpsertTableRowsRequestRequestTypeDef",
-    {
-        "workbookId": str,
-        "tableId": str,
-        "rowsToUpsert": Sequence["UpsertRowDataTypeDef"],
-    },
-)
-_OptionalBatchUpsertTableRowsRequestRequestTypeDef = TypedDict(
-    "_OptionalBatchUpsertTableRowsRequestRequestTypeDef",
-    {
-        "clientRequestToken": str,
-    },
-    total=False,
-)
-
-
-class BatchUpsertTableRowsRequestRequestTypeDef(
-    _RequiredBatchUpsertTableRowsRequestRequestTypeDef,
-    _OptionalBatchUpsertTableRowsRequestRequestTypeDef,
-):
-    pass
-
-
-BatchUpsertTableRowsResultTypeDef = TypedDict(
-    "BatchUpsertTableRowsResultTypeDef",
-    {
-        "rows": Dict[str, "UpsertRowsResultTypeDef"],
-        "workbookCursor": int,
-        "failedBatchItems": List["FailedBatchItemTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "rowIds": List[str],
+        "upsertAction": UpsertActionType,
     },
 )
 
@@ -253,14 +169,6 @@ ColumnMetadataTypeDef = TypedDict(
     },
 )
 
-CreateRowDataTypeDef = TypedDict(
-    "CreateRowDataTypeDef",
-    {
-        "batchItemId": str,
-        "cellsToCreate": Mapping[str, "CellInputTypeDef"],
-    },
-)
-
 DataItemTypeDef = TypedDict(
     "DataItemTypeDef",
     {
@@ -271,6 +179,30 @@ DataItemTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredDelimitedTextImportOptionsOutputTypeDef = TypedDict(
+    "_RequiredDelimitedTextImportOptionsOutputTypeDef",
+    {
+        "delimiter": str,
+    },
+)
+_OptionalDelimitedTextImportOptionsOutputTypeDef = TypedDict(
+    "_OptionalDelimitedTextImportOptionsOutputTypeDef",
+    {
+        "hasHeaderRow": bool,
+        "ignoreEmptyRows": bool,
+        "dataCharacterEncoding": ImportDataCharacterEncodingType,
+    },
+    total=False,
+)
+
+
+class DelimitedTextImportOptionsOutputTypeDef(
+    _RequiredDelimitedTextImportOptionsOutputTypeDef,
+    _OptionalDelimitedTextImportOptionsOutputTypeDef,
+):
+    pass
+
+
 _RequiredDelimitedTextImportOptionsTypeDef = TypedDict(
     "_RequiredDelimitedTextImportOptionsTypeDef",
     {
@@ -303,31 +235,20 @@ DescribeTableDataImportJobRequestRequestTypeDef = TypedDict(
     },
 )
 
-DescribeTableDataImportJobResultTypeDef = TypedDict(
-    "DescribeTableDataImportJobResultTypeDef",
+SourceDataColumnPropertiesOutputTypeDef = TypedDict(
+    "SourceDataColumnPropertiesOutputTypeDef",
     {
-        "jobStatus": TableDataImportJobStatusType,
-        "message": str,
-        "jobMetadata": "TableDataImportJobMetadataTypeDef",
-        "errorCode": ErrorCodeType,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-DestinationOptionsTypeDef = TypedDict(
-    "DestinationOptionsTypeDef",
-    {
-        "columnMap": Dict[str, "SourceDataColumnPropertiesTypeDef"],
+        "columnIndex": int,
     },
     total=False,
 )
 
-FailedBatchItemTypeDef = TypedDict(
-    "FailedBatchItemTypeDef",
+SourceDataColumnPropertiesTypeDef = TypedDict(
+    "SourceDataColumnPropertiesTypeDef",
     {
-        "id": str,
-        "errorMessage": str,
+        "columnIndex": int,
     },
+    total=False,
 )
 
 _RequiredFilterTypeDef = TypedDict(
@@ -349,41 +270,21 @@ class FilterTypeDef(_RequiredFilterTypeDef, _OptionalFilterTypeDef):
     pass
 
 
-_RequiredGetScreenDataRequestRequestTypeDef = TypedDict(
-    "_RequiredGetScreenDataRequestRequestTypeDef",
+VariableValueTypeDef = TypedDict(
+    "VariableValueTypeDef",
     {
-        "workbookId": str,
-        "appId": str,
-        "screenId": str,
+        "rawValue": str,
     },
 )
-_OptionalGetScreenDataRequestRequestTypeDef = TypedDict(
-    "_OptionalGetScreenDataRequestRequestTypeDef",
+
+ImportDataSourceConfigOutputTypeDef = TypedDict(
+    "ImportDataSourceConfigOutputTypeDef",
     {
-        "variables": Mapping[str, "VariableValueTypeDef"],
-        "maxResults": int,
-        "nextToken": str,
+        "dataSourceUrl": str,
     },
     total=False,
 )
 
-
-class GetScreenDataRequestRequestTypeDef(
-    _RequiredGetScreenDataRequestRequestTypeDef, _OptionalGetScreenDataRequestRequestTypeDef
-):
-    pass
-
-
-GetScreenDataResultTypeDef = TypedDict(
-    "GetScreenDataResultTypeDef",
-    {
-        "results": Dict[str, "ResultSetTypeDef"],
-        "workbookCursor": int,
-        "nextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 ImportDataSourceConfigTypeDef = TypedDict(
     "ImportDataSourceConfigTypeDef",
     {
@@ -392,13 +293,6 @@ ImportDataSourceConfigTypeDef = TypedDict(
     total=False,
 )
 
-ImportDataSourceTypeDef = TypedDict(
-    "ImportDataSourceTypeDef",
-    {
-        "dataSourceConfig": "ImportDataSourceConfigTypeDef",
-    },
-)
-
 ImportJobSubmitterTypeDef = TypedDict(
     "ImportJobSubmitterTypeDef",
     {
@@ -408,42 +302,6 @@ ImportJobSubmitterTypeDef = TypedDict(
     total=False,
 )
 
-ImportOptionsTypeDef = TypedDict(
-    "ImportOptionsTypeDef",
-    {
-        "destinationOptions": "DestinationOptionsTypeDef",
-        "delimitedTextOptions": "DelimitedTextImportOptionsTypeDef",
-    },
-    total=False,
-)
-
-_RequiredInvokeScreenAutomationRequestRequestTypeDef = TypedDict(
-    "_RequiredInvokeScreenAutomationRequestRequestTypeDef",
-    {
-        "workbookId": str,
-        "appId": str,
-        "screenId": str,
-        "screenAutomationId": str,
-    },
-)
-_OptionalInvokeScreenAutomationRequestRequestTypeDef = TypedDict(
-    "_OptionalInvokeScreenAutomationRequestRequestTypeDef",
-    {
-        "variables": Mapping[str, "VariableValueTypeDef"],
-        "rowId": str,
-        "clientRequestToken": str,
-    },
-    total=False,
-)
-
-
-class InvokeScreenAutomationRequestRequestTypeDef(
-    _RequiredInvokeScreenAutomationRequestRequestTypeDef,
-    _OptionalInvokeScreenAutomationRequestRequestTypeDef,
-):
-    pass
-
-
 InvokeScreenAutomationResultTypeDef = TypedDict(
     "InvokeScreenAutomationResultTypeDef",
     {
@@ -452,6 +310,29 @@ InvokeScreenAutomationResultTypeDef = TypedDict(
     },
 )
 
+_RequiredListTableColumnsRequestListTableColumnsPaginateTypeDef = TypedDict(
+    "_RequiredListTableColumnsRequestListTableColumnsPaginateTypeDef",
+    {
+        "workbookId": str,
+        "tableId": str,
+    },
+)
+_OptionalListTableColumnsRequestListTableColumnsPaginateTypeDef = TypedDict(
+    "_OptionalListTableColumnsRequestListTableColumnsPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
+
+class ListTableColumnsRequestListTableColumnsPaginateTypeDef(
+    _RequiredListTableColumnsRequestListTableColumnsPaginateTypeDef,
+    _OptionalListTableColumnsRequestListTableColumnsPaginateTypeDef,
+):
+    pass
+
+
 _RequiredListTableColumnsRequestRequestTypeDef = TypedDict(
     "_RequiredListTableColumnsRequestRequestTypeDef",
     {
@@ -474,15 +355,39 @@ class ListTableColumnsRequestRequestTypeDef(
     pass
 
 
-ListTableColumnsResultTypeDef = TypedDict(
-    "ListTableColumnsResultTypeDef",
+TableColumnTypeDef = TypedDict(
+    "TableColumnTypeDef",
     {
-        "tableColumns": List["TableColumnTypeDef"],
-        "nextToken": str,
-        "workbookCursor": int,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "tableColumnId": str,
+        "tableColumnName": str,
+        "format": FormatType,
+    },
+    total=False,
+)
+
+_RequiredListTableRowsRequestListTableRowsPaginateTypeDef = TypedDict(
+    "_RequiredListTableRowsRequestListTableRowsPaginateTypeDef",
+    {
+        "workbookId": str,
+        "tableId": str,
     },
 )
+_OptionalListTableRowsRequestListTableRowsPaginateTypeDef = TypedDict(
+    "_OptionalListTableRowsRequestListTableRowsPaginateTypeDef",
+    {
+        "rowIds": Sequence[str],
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
+
+class ListTableRowsRequestListTableRowsPaginateTypeDef(
+    _RequiredListTableRowsRequestListTableRowsPaginateTypeDef,
+    _OptionalListTableRowsRequestListTableRowsPaginateTypeDef,
+):
+    pass
+
 
 _RequiredListTableRowsRequestRequestTypeDef = TypedDict(
     "_RequiredListTableRowsRequestRequestTypeDef",
@@ -508,17 +413,27 @@ class ListTableRowsRequestRequestTypeDef(
     pass
 
 
-ListTableRowsResultTypeDef = TypedDict(
-    "ListTableRowsResultTypeDef",
+_RequiredListTablesRequestListTablesPaginateTypeDef = TypedDict(
+    "_RequiredListTablesRequestListTablesPaginateTypeDef",
     {
-        "columnIds": List[str],
-        "rows": List["TableRowTypeDef"],
-        "rowIdsNotFound": List[str],
-        "nextToken": str,
-        "workbookCursor": int,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "workbookId": str,
     },
 )
+_OptionalListTablesRequestListTablesPaginateTypeDef = TypedDict(
+    "_OptionalListTablesRequestListTablesPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
+
+class ListTablesRequestListTablesPaginateTypeDef(
+    _RequiredListTablesRequestListTablesPaginateTypeDef,
+    _OptionalListTablesRequestListTablesPaginateTypeDef,
+):
+    pass
+
 
 _RequiredListTablesRequestRequestTypeDef = TypedDict(
     "_RequiredListTablesRequestRequestTypeDef",
@@ -542,14 +457,13 @@ class ListTablesRequestRequestTypeDef(
     pass
 
 
-ListTablesResultTypeDef = TypedDict(
-    "ListTablesResultTypeDef",
+TableTypeDef = TypedDict(
+    "TableTypeDef",
     {
-        "tables": List["TableTypeDef"],
-        "nextToken": str,
-        "workbookCursor": int,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "tableId": str,
+        "tableName": str,
     },
+    total=False,
 )
 
 ListTagsForResourceRequestRequestTypeDef = TypedDict(
@@ -577,41 +491,6 @@ PaginatorConfigTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredQueryTableRowsRequestRequestTypeDef = TypedDict(
-    "_RequiredQueryTableRowsRequestRequestTypeDef",
-    {
-        "workbookId": str,
-        "tableId": str,
-        "filterFormula": "FilterTypeDef",
-    },
-)
-_OptionalQueryTableRowsRequestRequestTypeDef = TypedDict(
-    "_OptionalQueryTableRowsRequestRequestTypeDef",
-    {
-        "maxResults": int,
-        "nextToken": str,
-    },
-    total=False,
-)
-
-
-class QueryTableRowsRequestRequestTypeDef(
-    _RequiredQueryTableRowsRequestRequestTypeDef, _OptionalQueryTableRowsRequestRequestTypeDef
-):
-    pass
-
-
-QueryTableRowsResultTypeDef = TypedDict(
-    "QueryTableRowsResultTypeDef",
-    {
-        "columnIds": List[str],
-        "rows": List["TableRowTypeDef"],
-        "nextToken": str,
-        "workbookCursor": int,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 ResponseMetadataTypeDef = TypedDict(
     "ResponseMetadataTypeDef",
     {
@@ -623,53 +502,6 @@ ResponseMetadataTypeDef = TypedDict(
     },
 )
 
-_RequiredResultRowTypeDef = TypedDict(
-    "_RequiredResultRowTypeDef",
-    {
-        "dataItems": List["DataItemTypeDef"],
-    },
-)
-_OptionalResultRowTypeDef = TypedDict(
-    "_OptionalResultRowTypeDef",
-    {
-        "rowId": str,
-    },
-    total=False,
-)
-
-
-class ResultRowTypeDef(_RequiredResultRowTypeDef, _OptionalResultRowTypeDef):
-    pass
-
-
-ResultSetTypeDef = TypedDict(
-    "ResultSetTypeDef",
-    {
-        "headers": List["ColumnMetadataTypeDef"],
-        "rows": List["ResultRowTypeDef"],
-    },
-)
-
-SourceDataColumnPropertiesTypeDef = TypedDict(
-    "SourceDataColumnPropertiesTypeDef",
-    {
-        "columnIndex": int,
-    },
-    total=False,
-)
-
-StartTableDataImportJobRequestRequestTypeDef = TypedDict(
-    "StartTableDataImportJobRequestRequestTypeDef",
-    {
-        "workbookId": str,
-        "dataSource": "ImportDataSourceTypeDef",
-        "dataFormat": Literal["DELIMITED_TEXT"],
-        "destinationTableId": str,
-        "importOptions": "ImportOptionsTypeDef",
-        "clientRequestToken": str,
-    },
-)
-
 StartTableDataImportJobResultTypeDef = TypedDict(
     "StartTableDataImportJobResultTypeDef",
     {
@@ -679,43 +511,6 @@ StartTableDataImportJobResultTypeDef = TypedDict(
     },
 )
 
-TableColumnTypeDef = TypedDict(
-    "TableColumnTypeDef",
-    {
-        "tableColumnId": str,
-        "tableColumnName": str,
-        "format": FormatType,
-    },
-    total=False,
-)
-
-TableDataImportJobMetadataTypeDef = TypedDict(
-    "TableDataImportJobMetadataTypeDef",
-    {
-        "submitter": "ImportJobSubmitterTypeDef",
-        "submitTime": datetime,
-        "importOptions": "ImportOptionsTypeDef",
-        "dataSource": "ImportDataSourceTypeDef",
-    },
-)
-
-TableRowTypeDef = TypedDict(
-    "TableRowTypeDef",
-    {
-        "rowId": str,
-        "cells": List["CellTypeDef"],
-    },
-)
-
-TableTypeDef = TypedDict(
-    "TableTypeDef",
-    {
-        "tableId": str,
-        "tableName": str,
-    },
-    total=False,
-)
-
 TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
     {
@@ -732,34 +527,406 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
+BatchCreateTableRowsResultTypeDef = TypedDict(
+    "BatchCreateTableRowsResultTypeDef",
+    {
+        "workbookCursor": int,
+        "createdRows": Dict[str, str],
+        "failedBatchItems": List[FailedBatchItemTypeDef],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+BatchDeleteTableRowsResultTypeDef = TypedDict(
+    "BatchDeleteTableRowsResultTypeDef",
+    {
+        "workbookCursor": int,
+        "failedBatchItems": List[FailedBatchItemTypeDef],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+BatchUpdateTableRowsResultTypeDef = TypedDict(
+    "BatchUpdateTableRowsResultTypeDef",
+    {
+        "workbookCursor": int,
+        "failedBatchItems": List[FailedBatchItemTypeDef],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+BatchUpsertTableRowsResultTypeDef = TypedDict(
+    "BatchUpsertTableRowsResultTypeDef",
+    {
+        "rows": Dict[str, UpsertRowsResultTypeDef],
+        "workbookCursor": int,
+        "failedBatchItems": List[FailedBatchItemTypeDef],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+CreateRowDataTypeDef = TypedDict(
+    "CreateRowDataTypeDef",
+    {
+        "batchItemId": str,
+        "cellsToCreate": Mapping[str, CellInputTypeDef],
+    },
+)
+
 UpdateRowDataTypeDef = TypedDict(
     "UpdateRowDataTypeDef",
     {
         "rowId": str,
-        "cellsToUpdate": Mapping[str, "CellInputTypeDef"],
+        "cellsToUpdate": Mapping[str, CellInputTypeDef],
     },
 )
 
+TableRowTypeDef = TypedDict(
+    "TableRowTypeDef",
+    {
+        "rowId": str,
+        "cells": List[CellTypeDef],
+    },
+)
+
+_RequiredResultRowTypeDef = TypedDict(
+    "_RequiredResultRowTypeDef",
+    {
+        "dataItems": List[DataItemTypeDef],
+    },
+)
+_OptionalResultRowTypeDef = TypedDict(
+    "_OptionalResultRowTypeDef",
+    {
+        "rowId": str,
+    },
+    total=False,
+)
+
+
+class ResultRowTypeDef(_RequiredResultRowTypeDef, _OptionalResultRowTypeDef):
+    pass
+
+
+DestinationOptionsOutputTypeDef = TypedDict(
+    "DestinationOptionsOutputTypeDef",
+    {
+        "columnMap": Dict[str, SourceDataColumnPropertiesOutputTypeDef],
+    },
+    total=False,
+)
+
+DestinationOptionsTypeDef = TypedDict(
+    "DestinationOptionsTypeDef",
+    {
+        "columnMap": Mapping[str, SourceDataColumnPropertiesTypeDef],
+    },
+    total=False,
+)
+
+_RequiredQueryTableRowsRequestQueryTableRowsPaginateTypeDef = TypedDict(
+    "_RequiredQueryTableRowsRequestQueryTableRowsPaginateTypeDef",
+    {
+        "workbookId": str,
+        "tableId": str,
+        "filterFormula": FilterTypeDef,
+    },
+)
+_OptionalQueryTableRowsRequestQueryTableRowsPaginateTypeDef = TypedDict(
+    "_OptionalQueryTableRowsRequestQueryTableRowsPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
+
+class QueryTableRowsRequestQueryTableRowsPaginateTypeDef(
+    _RequiredQueryTableRowsRequestQueryTableRowsPaginateTypeDef,
+    _OptionalQueryTableRowsRequestQueryTableRowsPaginateTypeDef,
+):
+    pass
+
+
+_RequiredQueryTableRowsRequestRequestTypeDef = TypedDict(
+    "_RequiredQueryTableRowsRequestRequestTypeDef",
+    {
+        "workbookId": str,
+        "tableId": str,
+        "filterFormula": FilterTypeDef,
+    },
+)
+_OptionalQueryTableRowsRequestRequestTypeDef = TypedDict(
+    "_OptionalQueryTableRowsRequestRequestTypeDef",
+    {
+        "maxResults": int,
+        "nextToken": str,
+    },
+    total=False,
+)
+
+
+class QueryTableRowsRequestRequestTypeDef(
+    _RequiredQueryTableRowsRequestRequestTypeDef, _OptionalQueryTableRowsRequestRequestTypeDef
+):
+    pass
+
+
 UpsertRowDataTypeDef = TypedDict(
     "UpsertRowDataTypeDef",
     {
         "batchItemId": str,
-        "filter": "FilterTypeDef",
-        "cellsToUpdate": Mapping[str, "CellInputTypeDef"],
+        "filter": FilterTypeDef,
+        "cellsToUpdate": Mapping[str, CellInputTypeDef],
     },
 )
 
-UpsertRowsResultTypeDef = TypedDict(
-    "UpsertRowsResultTypeDef",
+_RequiredGetScreenDataRequestRequestTypeDef = TypedDict(
+    "_RequiredGetScreenDataRequestRequestTypeDef",
     {
-        "rowIds": List[str],
-        "upsertAction": UpsertActionType,
+        "workbookId": str,
+        "appId": str,
+        "screenId": str,
+    },
+)
+_OptionalGetScreenDataRequestRequestTypeDef = TypedDict(
+    "_OptionalGetScreenDataRequestRequestTypeDef",
+    {
+        "variables": Mapping[str, VariableValueTypeDef],
+        "maxResults": int,
+        "nextToken": str,
+    },
+    total=False,
+)
+
+
+class GetScreenDataRequestRequestTypeDef(
+    _RequiredGetScreenDataRequestRequestTypeDef, _OptionalGetScreenDataRequestRequestTypeDef
+):
+    pass
+
+
+_RequiredInvokeScreenAutomationRequestRequestTypeDef = TypedDict(
+    "_RequiredInvokeScreenAutomationRequestRequestTypeDef",
+    {
+        "workbookId": str,
+        "appId": str,
+        "screenId": str,
+        "screenAutomationId": str,
+    },
+)
+_OptionalInvokeScreenAutomationRequestRequestTypeDef = TypedDict(
+    "_OptionalInvokeScreenAutomationRequestRequestTypeDef",
+    {
+        "variables": Mapping[str, VariableValueTypeDef],
+        "rowId": str,
+        "clientRequestToken": str,
+    },
+    total=False,
+)
+
+
+class InvokeScreenAutomationRequestRequestTypeDef(
+    _RequiredInvokeScreenAutomationRequestRequestTypeDef,
+    _OptionalInvokeScreenAutomationRequestRequestTypeDef,
+):
+    pass
+
+
+ImportDataSourceOutputTypeDef = TypedDict(
+    "ImportDataSourceOutputTypeDef",
+    {
+        "dataSourceConfig": ImportDataSourceConfigOutputTypeDef,
     },
 )
 
-VariableValueTypeDef = TypedDict(
-    "VariableValueTypeDef",
+ImportDataSourceTypeDef = TypedDict(
+    "ImportDataSourceTypeDef",
     {
-        "rawValue": str,
+        "dataSourceConfig": ImportDataSourceConfigTypeDef,
+    },
+)
+
+ListTableColumnsResultTypeDef = TypedDict(
+    "ListTableColumnsResultTypeDef",
+    {
+        "tableColumns": List[TableColumnTypeDef],
+        "nextToken": str,
+        "workbookCursor": int,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListTablesResultTypeDef = TypedDict(
+    "ListTablesResultTypeDef",
+    {
+        "tables": List[TableTypeDef],
+        "nextToken": str,
+        "workbookCursor": int,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredBatchCreateTableRowsRequestRequestTypeDef = TypedDict(
+    "_RequiredBatchCreateTableRowsRequestRequestTypeDef",
+    {
+        "workbookId": str,
+        "tableId": str,
+        "rowsToCreate": Sequence[CreateRowDataTypeDef],
+    },
+)
+_OptionalBatchCreateTableRowsRequestRequestTypeDef = TypedDict(
+    "_OptionalBatchCreateTableRowsRequestRequestTypeDef",
+    {
+        "clientRequestToken": str,
+    },
+    total=False,
+)
+
+
+class BatchCreateTableRowsRequestRequestTypeDef(
+    _RequiredBatchCreateTableRowsRequestRequestTypeDef,
+    _OptionalBatchCreateTableRowsRequestRequestTypeDef,
+):
+    pass
+
+
+_RequiredBatchUpdateTableRowsRequestRequestTypeDef = TypedDict(
+    "_RequiredBatchUpdateTableRowsRequestRequestTypeDef",
+    {
+        "workbookId": str,
+        "tableId": str,
+        "rowsToUpdate": Sequence[UpdateRowDataTypeDef],
+    },
+)
+_OptionalBatchUpdateTableRowsRequestRequestTypeDef = TypedDict(
+    "_OptionalBatchUpdateTableRowsRequestRequestTypeDef",
+    {
+        "clientRequestToken": str,
+    },
+    total=False,
+)
+
+
+class BatchUpdateTableRowsRequestRequestTypeDef(
+    _RequiredBatchUpdateTableRowsRequestRequestTypeDef,
+    _OptionalBatchUpdateTableRowsRequestRequestTypeDef,
+):
+    pass
+
+
+ListTableRowsResultTypeDef = TypedDict(
+    "ListTableRowsResultTypeDef",
+    {
+        "columnIds": List[str],
+        "rows": List[TableRowTypeDef],
+        "rowIdsNotFound": List[str],
+        "nextToken": str,
+        "workbookCursor": int,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+QueryTableRowsResultTypeDef = TypedDict(
+    "QueryTableRowsResultTypeDef",
+    {
+        "columnIds": List[str],
+        "rows": List[TableRowTypeDef],
+        "nextToken": str,
+        "workbookCursor": int,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ResultSetTypeDef = TypedDict(
+    "ResultSetTypeDef",
+    {
+        "headers": List[ColumnMetadataTypeDef],
+        "rows": List[ResultRowTypeDef],
+    },
+)
+
+ImportOptionsOutputTypeDef = TypedDict(
+    "ImportOptionsOutputTypeDef",
+    {
+        "destinationOptions": DestinationOptionsOutputTypeDef,
+        "delimitedTextOptions": DelimitedTextImportOptionsOutputTypeDef,
+    },
+    total=False,
+)
+
+ImportOptionsTypeDef = TypedDict(
+    "ImportOptionsTypeDef",
+    {
+        "destinationOptions": DestinationOptionsTypeDef,
+        "delimitedTextOptions": DelimitedTextImportOptionsTypeDef,
+    },
+    total=False,
+)
+
+_RequiredBatchUpsertTableRowsRequestRequestTypeDef = TypedDict(
+    "_RequiredBatchUpsertTableRowsRequestRequestTypeDef",
+    {
+        "workbookId": str,
+        "tableId": str,
+        "rowsToUpsert": Sequence[UpsertRowDataTypeDef],
+    },
+)
+_OptionalBatchUpsertTableRowsRequestRequestTypeDef = TypedDict(
+    "_OptionalBatchUpsertTableRowsRequestRequestTypeDef",
+    {
+        "clientRequestToken": str,
+    },
+    total=False,
+)
+
+
+class BatchUpsertTableRowsRequestRequestTypeDef(
+    _RequiredBatchUpsertTableRowsRequestRequestTypeDef,
+    _OptionalBatchUpsertTableRowsRequestRequestTypeDef,
+):
+    pass
+
+
+GetScreenDataResultTypeDef = TypedDict(
+    "GetScreenDataResultTypeDef",
+    {
+        "results": Dict[str, ResultSetTypeDef],
+        "workbookCursor": int,
+        "nextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+TableDataImportJobMetadataTypeDef = TypedDict(
+    "TableDataImportJobMetadataTypeDef",
+    {
+        "submitter": ImportJobSubmitterTypeDef,
+        "submitTime": datetime,
+        "importOptions": ImportOptionsOutputTypeDef,
+        "dataSource": ImportDataSourceOutputTypeDef,
+    },
+)
+
+StartTableDataImportJobRequestRequestTypeDef = TypedDict(
+    "StartTableDataImportJobRequestRequestTypeDef",
+    {
+        "workbookId": str,
+        "dataSource": ImportDataSourceTypeDef,
+        "dataFormat": Literal["DELIMITED_TEXT"],
+        "destinationTableId": str,
+        "importOptions": ImportOptionsTypeDef,
+        "clientRequestToken": str,
+    },
+)
+
+DescribeTableDataImportJobResultTypeDef = TypedDict(
+    "DescribeTableDataImportJobResultTypeDef",
+    {
+        "jobStatus": TableDataImportJobStatusType,
+        "message": str,
+        "jobMetadata": TableDataImportJobMetadataTypeDef,
+        "errorCode": ErrorCodeType,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
